@@ -3,7 +3,6 @@
 #include "tables.h"
 #include "utils.h"
 #include "H5Zlzo.h"  		       /* Import FILTER_LZO */
-#include "H5Zucl.h"  		       /* Import FILTER_UCL */
 #include "H5Zbzip2.h"  		       /* Import FILTER_BZIP2 */
 
 #include <string.h>
@@ -35,7 +34,6 @@ herr_t H5ARRAYmake( hid_t loc_id,
 		    const char *dset_name,
 		    const char *class_,
 		    const char *title,
-		    const char *flavor,
 		    const char *obversion,    /* The Array VERSION number */
 		    const int rank,
 		    const hsize_t *dims,
@@ -57,8 +55,7 @@ herr_t H5ARRAYmake( hid_t loc_id,
  int     chunked = 0;
  int     i;
 
- /* Check if the array has to be chunked or not */
- /*if (extdim >= 0) {*/
+ /* Check whether the array has to be chunked or not */
  if (dims_chunk) {
    chunked = 1;
  }
@@ -68,7 +65,6 @@ herr_t H5ARRAYmake( hid_t loc_id,
    if(!maxdims) return -1;
 
    for(i=0;i<rank;i++) {
-/*      printf("dims_chunk[%d]: %d\n", i, dims_chunk[i]); */
      if (i == extdim) {
        maxdims[i] = H5S_UNLIMITED;
      }
@@ -128,11 +124,6 @@ herr_t H5ARRAYmake( hid_t loc_id,
        if ( H5Pset_filter( plist_id, FILTER_LZO, H5Z_FLAG_OPTIONAL, 3, cd_values) < 0 )
 	 return -1;
      }
-     /* The UCL compress does accept parameters */
-     else if (strcmp(complib, "ucl") == 0) {
-       if ( H5Pset_filter( plist_id, FILTER_UCL, H5Z_FLAG_OPTIONAL, 3, cd_values) < 0 )
-	 return -1;
-     }
      /* The bzip2 compress does accept parameters */
      else if (strcmp(complib, "bzip2") == 0) {
        if ( H5Pset_filter( plist_id, FILTER_BZIP2, H5Z_FLAG_OPTIONAL, 3, cd_values) < 0 )
@@ -184,15 +175,11 @@ herr_t H5ARRAYmake( hid_t loc_id,
      goto out;
  if (extdim >= 0) {
    /* Attach the EXTDIM attribute in case of enlargeable arrays */
-   if (H5ATTR_set_attribute_numerical(dataset_id, "EXTDIM",
-                                    H5T_NATIVE_INT, &extdim) < 0 )
+   if (H5ATTRset_attribute( dataset_id, "EXTDIM", H5T_NATIVE_INT,
+			    0, NULL, (char *)&extdim ) < 0 )
      goto out;
  }
 
- /* Attach the FLAVOR attribute */
- if ( H5ATTRset_attribute_string( dataset_id, "FLAVOR", flavor ) < 0 )
-   goto out;
-
  /* Attach the VERSION attribute */
  if ( H5ATTRset_attribute_string( dataset_id, "VERSION", obversion ) < 0 )
   goto out;
@@ -597,7 +584,6 @@ herr_t H5ARRAYreadSlice( hid_t dataset_id,
  int      rank;
  int      i;
 
-/*  printf("H5ARRAYreadSlice.dataset_id-->%ld\n", dataset_id); */
   /* Get the dataspace handle */
  if ( (space_id = H5Dget_space( dataset_id )) < 0 )
   goto out;
@@ -617,7 +603,7 @@ herr_t H5ARRAYreadSlice( hid_t dataset_id,
      goto out;
 
    for(i=0;i<rank;i++) {
-     count[i] = ((stop[i] - start[i] - 1) / step[i]) + 1;
+     count[i] = get_len_of_range(start[i], stop[i], step[i]);
      if ( stop[i] > dims[i] ) {
        printf("Asking for a range of rows exceeding the available ones!.\n");
        goto out;
@@ -625,7 +611,8 @@ herr_t H5ARRAYreadSlice( hid_t dataset_id,
    }
 
    /* Define a hyperslab in the dataset of the size of the records */
-   if ( H5Sselect_hyperslab( space_id, H5S_SELECT_SET, offset, stride, count, NULL) < 0 )
+   if ( H5Sselect_hyperslab( space_id, H5S_SELECT_SET, offset, stride,
+			     count, NULL) < 0 )
      goto out;
 
    /* Create a memory dataspace handle */
@@ -633,13 +620,14 @@ herr_t H5ARRAYreadSlice( hid_t dataset_id,
      goto out;
 
    /* Read */
-   if ( H5Dread( dataset_id, type_id, mem_space_id, space_id, H5P_DEFAULT, data ) < 0 )
+   if ( H5Dread( dataset_id, type_id, mem_space_id, space_id, H5P_DEFAULT,
+		 data ) < 0 )
      goto out;
 
    /* Release resources */
    free(dims);
    free(count);
-
+ 
    /* Terminate access to the memory dataspace */
    if ( H5Sclose( mem_space_id ) < 0 )
      goto out;
@@ -724,7 +712,7 @@ herr_t H5ARRAYreadIndex( hid_t   dataset_id,
      goto out;
 
    for(i=0;i<rank;i++) {
-     count[i] = ((stop[i] - start[i] - 1) / step[i]) + 1;
+     count[i] = get_len_of_range(start[i], stop[i], step[i]);
      if ( stop[i] > dims[i] ) {
        printf("Asking for a range of rows exceeding the available ones!.\n");
        goto out;
@@ -732,7 +720,8 @@ herr_t H5ARRAYreadIndex( hid_t   dataset_id,
    }
 
    /* Define a hyperslab in the dataset of the size of the records */
-   if ( H5Sselect_hyperslab( space_id, H5S_SELECT_SET, offset, stride, count, NULL) < 0 )
+   if ( H5Sselect_hyperslab( space_id, H5S_SELECT_SET, offset, stride,
+			     count, NULL) < 0 )
      goto out;
 
    /* If we want the complementary, do a NOTA against all the row */
@@ -740,11 +729,8 @@ herr_t H5ARRAYreadIndex( hid_t   dataset_id,
      offset2[0] = offset[0]; count2[0] = count[0];
      offset2[1] = 0; count2[1] = dims[1]; /* All the row */
      count[0] = 1; count[1] = dims[1] - count[1]; /* For memory dataspace */
-/*      printf("dims[%d]: %d\n", i, (int)dims[i]); */
-/*      printf("offset2[%d]: %d\n", i, (int)offset2[i]); */
-/*      printf("count2[%d]: %d\n", i, (int)count2[i]); */
-/*      printf("count[%d]: %d\n", i, (int)count[i]); */
-     if ( H5Sselect_hyperslab( space_id, H5S_SELECT_NOTA, offset2, stride, count2, NULL) < 0 )
+     if ( H5Sselect_hyperslab( space_id, H5S_SELECT_NOTA, offset2, stride,
+			       count2, NULL) < 0 )
        goto out;
    }
 
@@ -847,67 +833,42 @@ out:
 
 
 /* Modified version of H5LTget_dataset_info. */
-/* Addition: Now, this routine can deal with both array and
-   atomic datatypes. 2003-01-29 */
 
 herr_t H5ARRAYget_info( hid_t dataset_id,
 			hid_t type_id,
 			hsize_t *dims,
 			hsize_t *maxdims,
-			hid_t *super_type_id,
-			H5T_class_t *super_class_id,
+			H5T_class_t *class_id,
 			char *byteorder)
 {
-
   hid_t       space_id;
-  H5T_class_t class_arr_id;
 
   /* Get the class. */
-  class_arr_id = H5Tget_class( type_id );
+  *class_id = H5Tget_class( type_id );
 
-  /* Check if this is an array class object*/
-  if ( class_arr_id == H5T_ARRAY) {
+  /* Get the dataspace handle */
+  if ( (space_id = H5Dget_space( dataset_id )) < 0 )
+    goto out;
 
-    /* Get the array base component. This will be released later on. */
-    *super_type_id = H5Tget_super( type_id );
+  /* Get dimensions */
+  if ( H5Sget_simple_extent_dims( space_id, dims, maxdims) < 0 )
+    goto out;
 
-    /* Get the class of base component. */
-    *super_class_id = H5Tget_class( *super_type_id );
-
-    /* Get dimensions */
-    if ( H5Tget_array_dims(type_id, dims, NULL) < 0 )
-      goto out;
-
-  }
-  else {
-    *super_class_id = class_arr_id;
-
-    /* Do a copy of type_id. This will be released later on. */
-    *super_type_id = H5Tcopy(type_id);
-
-    /* Get the dataspace handle */
-    if ( (space_id = H5Dget_space( dataset_id )) < 0 )
-      goto out;
-
-    /* Get dimensions */
-    if ( H5Sget_simple_extent_dims( space_id, dims, maxdims) < 0 )
-      goto out;
-
-    /* Terminate access to the dataspace */
-    if ( H5Sclose( space_id ) < 0 )
-      goto out;
-
-  }
+  /* Terminate access to the dataspace */
+  if ( H5Sclose( space_id ) < 0 )
+    goto out;
 
   /* Get the byteorder */
-  /* Only integer, float, time and enumerate classes can be byteordered */
-  if ((*super_class_id == H5T_INTEGER) || (*super_class_id == H5T_FLOAT)
-      || (*super_class_id == H5T_BITFIELD) || (*super_class_id == H5T_COMPOUND)
-      || (*super_class_id == H5T_TIME) || (*super_class_id == H5T_ENUM)) {
-    get_order(*super_type_id, byteorder);
+  /* Only integer, float, time, enumerate and array classes can be
+     byteordered */
+  if ((*class_id == H5T_INTEGER) || (*class_id == H5T_FLOAT)
+      || (*class_id == H5T_BITFIELD) || (*class_id == H5T_COMPOUND)
+      || (*class_id == H5T_TIME) || (*class_id == H5T_ENUM)
+      || (*class_id == H5T_ARRAY)) {
+    get_order(type_id, byteorder);
   }
   else {
-    strcpy(byteorder, "non-relevant");
+    strcpy(byteorder, "irrelevant");
   }
 
   return 0;
@@ -920,12 +881,11 @@ out:
 
 
 /*-------------------------------------------------------------------------
- * Function: H5ARRAYget_chunksize
+ * Function: H5ARRAYget_chunkshape
  *
- * Purpose: Gets the chunksize along the extensible dimension of a
- *          carray/earray.
+ * Purpose: Gets the chunkshape of a dataset.
  *
- * Return: Success: chunksize, Failure: -1
+ * Return: Success: chunkshape, Failure: -1
  *
  * Programmer: Francesc Altet
  *
@@ -934,9 +894,9 @@ out:
  *-------------------------------------------------------------------------
  */
 
-herr_t H5ARRAYget_chunksize( hid_t dataset_id,
-			     int rank,
-			     hsize_t *dims_chunk)
+herr_t H5ARRAYget_chunkshape( hid_t dataset_id,
+			      int rank,
+			      hsize_t *dims_chunk)
 {
   hid_t        plist_id;
   H5D_layout_t layout;
@@ -949,10 +909,10 @@ herr_t H5ARRAYget_chunksize( hid_t dataset_id,
   layout = H5Pget_layout(plist_id);
   if (layout != H5D_CHUNKED) {
     H5Pclose( plist_id );
-    goto out;
+    return -1;
   }
 
-  /* Get the chunksize for all dimensions */
+  /* Get the chunkshape for all dimensions */
   if (H5Pget_chunk(plist_id, rank, dims_chunk ) < 0 )
     goto out;
 
