@@ -11,10 +11,8 @@ herr_t H5VLARRAYmake( hid_t loc_id,
 		      const char *dset_name,
 		      const char *class_,
 		      const char *title,
-		      const char *flavor,
 		      const char *obversion,    /* The Array VERSION number */
 		      const int rank,
-		      const int scalar,
 		      const hsize_t *dims,
 		      hid_t type_id,
 		      hsize_t chunk_size,
