@@ -3,7 +3,6 @@
 /* #include <string.h> */
 #include "version.h"
 #include "H5Zlzo.h"  		       /* Import FILTER_LZO */
-#include "H5Zucl.h"  		       /* Import FILTER_UCL */
 #include "H5Zbzip2.h"  		       /* Import FILTER_BZIP2 */
 
 
@@ -60,13 +59,15 @@ int getLibrary(char *libname) {
 #endif  /* Win32 */
 
 herr_t set_cache_size(hid_t file_id, size_t cache_size) {
+#if H5_VERS_MAJOR == 1 && H5_VERS_MINOR >= 7
+  /* MSVS2005 chokes on declarations after statements */
+  H5AC_cache_config_t config;
+#endif /* if H5_VERSION < "1.7" */
   herr_t code;
 
   code = 0;
 
 #if H5_VERS_MAJOR == 1 && H5_VERS_MINOR >= 7
-  H5AC_cache_config_t config;
-
   config.version = H5AC__CURR_CACHE_CONFIG_VERSION;
   code = H5Fget_mdc_config(file_id, &config);
   config.set_initial_size = TRUE;
@@ -430,7 +431,7 @@ PyObject *H5UIget_info( hid_t loc_id,
     }
   }
   else {
-    strcpy(byteorder, "non-relevant");
+    strcpy(byteorder, "irrelevant");
   }
 
   /* End access to the dataset */
@@ -447,6 +448,7 @@ out:
 
 }
 
+
 /* Extract a slice index from a PyLong, and store in *pi.  Silently
    reduce values larger than LONGLONG_MAX to LONGLONG_MAX, and
    silently boost values less than -LONGLONG_MAX to 0.  Return 0 on
@@ -457,17 +459,21 @@ out:
    F. Altet 2005-05-08
 */
 
+/* Replaced LONLONG_MAX by ll_max because AIX does define the former.
+   F. Altet 2006-10-23
+ */
+
 hsize_t _PyEval_SliceIndex_modif(PyObject *v, hsize_t *pi)
 {
-  PY_LONG_LONG LONGLONG_MAX;
+  PY_LONG_LONG ll_max;
 
-  /* I think it should be a more efficient way to know LONGLONG_MAX,
+  /* I think it should be a more efficient way to know ll_max,
    but this should work on every platform, be 32 or 64 bits.
    F. Altet 2005-05-08
   */
 
-/*  LONGLONG_MAX = (PY_LONG_LONG) (pow(2, 63) - 1); */ /* Works on Unix */
-  LONGLONG_MAX = (PY_LONG_LONG) (pow(2, 62) - 1); /* Safer on Windows */
+/*  ll_max = (PY_LONG_LONG) (pow(2, 63) - 1); */ /* Works on Unix */
+  ll_max = (PY_LONG_LONG) (pow(2, 62) - 1); /* Safer on Windows */
 
   if (v != NULL) {
     PY_LONG_LONG x;
@@ -482,10 +488,10 @@ hsize_t _PyEval_SliceIndex_modif(PyObject *v, hsize_t *pi)
       return 0;
     }
     /* Truncate -- very long indices are truncated anyway */
-    if (x > LONGLONG_MAX)
-      x = LONGLONG_MAX;
-    else if (x < -LONGLONG_MAX)
-      x = -LONGLONG_MAX;
+    if (x > ll_max)
+      x = ll_max;
+    else if (x < -ll_max)
+      x = -ll_max;
     *pi = x;
   }
   return 1;
@@ -529,7 +535,7 @@ hsize_t getIndicesExt(PyObject *s, hsize_t length,
                 if (!_PyEval_SliceIndex_modif(r->start, start)) return -1;
                 if ((PY_LONG_LONG)*start < 0L) *start += length;
                 if ((PY_LONG_LONG)*start < 0) *start = ((PY_LONG_LONG)*step < 0) ? -1 : 0;
-                if ((PY_LONG_LONG)*start >= length)
+                if ((PY_LONG_LONG)*start >= (PY_LONG_LONG)length)
                         *start = ((PY_LONG_LONG)*step < 0) ? length - 1 : length;
         }
 
@@ -540,7 +546,7 @@ hsize_t getIndicesExt(PyObject *s, hsize_t length,
                 if (!_PyEval_SliceIndex_modif(r->stop, stop)) return -1;
                 if ((PY_LONG_LONG)*stop < 0) *stop += length;
                 if ((PY_LONG_LONG)*stop < 0) *stop = -1;
-                if ((PY_LONG_LONG)*stop > length) *stop = length;
+                if ((PY_LONG_LONG)*stop > (PY_LONG_LONG)length) *stop = length;
         }
 
         if (((PY_LONG_LONG)*step < 0 && (PY_LONG_LONG)*stop >= (PY_LONG_LONG)*start)
@@ -566,32 +572,6 @@ hsize_t getIndicesExt(PyObject *s, hsize_t length,
    Adapted to support Tables by F. Altet September 2004.
 */
 
-/* Return the byteorder of a complex datatype.
-   It is obtained from the real part,
-   which is the first member. */
-static H5T_order_t get_complex_order(hid_t type_id) {
-  hid_t class_id, base_type_id;
-  hid_t real_type = 0;
-  H5T_order_t result = 0;
-
-  class_id = H5Tget_class(type_id);
-  if (class_id == H5T_COMPOUND) {
-    real_type = H5Tget_member_type(type_id, 0);
-  }
-  else if (class_id == H5T_ARRAY) {
-    /* Get the array base component */
-    base_type_id = H5Tget_super(type_id);
-    /* Get the type of real component. */
-    real_type = H5Tget_member_type(base_type_id, 0);
-    H5Tclose(base_type_id);
-  }
-  if ((class_id == H5T_COMPOUND) || (class_id == H5T_ARRAY)) {
-    result = H5Tget_order(real_type);
-    H5Tclose(real_type);
-  }
-  return result;
-}
-
 /* Test whether the datatype is of class complex
    return 1 if it corresponds to our complex class, otherwise 0 */
 /* This may be ultimately confused with nested types with 2 components
@@ -633,9 +613,35 @@ int is_complex(hid_t type_id) {
   return result;
 }
 
+
+/* Return the byteorder of a complex datatype.
+   It is obtained from the real part, which is the first member. */
+static H5T_order_t get_complex_order(hid_t type_id) {
+  hid_t class_id, base_type_id;
+  hid_t real_type = 0;
+  H5T_order_t result = 0;
+
+  class_id = H5Tget_class(type_id);
+  if (class_id == H5T_COMPOUND) {
+    real_type = H5Tget_member_type(type_id, 0);
+  }
+  else if (class_id == H5T_ARRAY) {
+    /* Get the array base component */
+    base_type_id = H5Tget_super(type_id);
+    /* Get the type of real component. */
+    real_type = H5Tget_member_type(base_type_id, 0);
+    H5Tclose(base_type_id);
+  }
+  if ((class_id == H5T_COMPOUND) || (class_id == H5T_ARRAY)) {
+    result = H5Tget_order(real_type);
+    H5Tclose(real_type);
+  }
+  return result;
+}
+
+
 /* Return the byteorder of a HDF5 data type */
-/* This is effectively an extension of H5Tget_order
-   to handle complex types */
+/* This is actually an extension of H5Tget_order to handle complex types */
 herr_t get_order(hid_t type_id, char *byteorder) {
   hid_t class_id;
   H5T_order_t h5byteorder;
@@ -657,26 +663,34 @@ herr_t get_order(hid_t type_id, char *byteorder) {
     return h5byteorder;
   }
   else if (h5byteorder == H5T_ORDER_NONE ) {
-    strcpy(byteorder, "non-relevant");
+    strcpy(byteorder, "irrelevant");
     return h5byteorder;
   }
   else {
+    /* This should never happen! */
     fprintf(stderr, "Error: unsupported byteorder <%d>\n", h5byteorder);
     strcpy(byteorder, "unsupported");
     return -1;
   }
 }
 
+
 /* Set the byteorder of type_id. */
 /* This only works for datatypes that are not Complex. However,
-   this types should already been created with correct byteorder */
+   these types should already been created with correct byteorder */
 herr_t set_order(hid_t type_id, const char *byteorder) {
   herr_t status=0;
+
   if (! is_complex(type_id)) {
     if (strcmp(byteorder, "little") == 0)
       status = H5Tset_order(type_id, H5T_ORDER_LE);
     else if (strcmp(byteorder, "big") == 0)
-      status = H5Tset_order(type_id, H5T_ORDER_BE );
+      status = H5Tset_order(type_id, H5T_ORDER_BE);
+    else if (strcmp(byteorder, "irrelevant") == 0) {
+      /* Do nothing because 'irrelevant' doesn't require setting the
+         byteorder explicitely */
+/*       status = H5Tset_order(type_id, H5T_ORDER_NONE ); */
+    }
     else {
       fprintf(stderr, "Error: unsupported byteorder <%s>\n", byteorder);
       status = -1;
@@ -685,43 +699,42 @@ herr_t set_order(hid_t type_id, const char *byteorder) {
   return status;
 }
 
+
 /* Create a HDF5 compound datatype that represents complex numbers
-   defined by numarray as Complex64.
-   We must set the byteorder before we create the type */
-hid_t create_native_complex64(const char *byteorder) {
+   defined by numpy as complex64. */
+hid_t create_ieee_complex64(const char *byteorder) {
   hid_t float_id, complex_id;
 
-  float_id = H5Tcopy(H5T_NATIVE_DOUBLE);
-  complex_id = H5Tcreate (H5T_COMPOUND, sizeof(Complex64));
-  set_order(float_id, byteorder);
-  H5Tinsert (complex_id, "r", HOFFSET(Complex64,r),
-	     float_id);
-  H5Tinsert (complex_id, "i", HOFFSET(Complex64,i),
-	     float_id);
+  complex_id = H5Tcreate(H5T_COMPOUND, sizeof(npy_complex64));
+  if (strcmp(byteorder, "little") == 0)
+    float_id = H5Tcopy(H5T_IEEE_F32LE);
+  else
+    float_id = H5Tcopy(H5T_IEEE_F32BE);
+  H5Tinsert(complex_id, "r", HOFFSET(npy_complex64, real), float_id);
+  H5Tinsert(complex_id, "i", HOFFSET(npy_complex64, imag), float_id);
   H5Tclose(float_id);
   return complex_id;
 }
 
-/* Create a HDF5 compound datatype that represents complex numbers
-   defined by numarray as Complex32.
-   We must set the byteorder before we create the type */
-hid_t create_native_complex32(const char *byteorder) {
+
+/* Counterpart for complex128 */
+hid_t create_ieee_complex128(const char *byteorder) {
   hid_t float_id, complex_id;
-  float_id = H5Tcopy(H5T_NATIVE_FLOAT);
-  complex_id = H5Tcreate (H5T_COMPOUND, sizeof(Complex32));
-  set_order(float_id, byteorder);
-  H5Tinsert (complex_id, "r", HOFFSET(Complex32,r),
-	     float_id);
-  H5Tinsert (complex_id, "i", HOFFSET(Complex32,i),
-	     float_id);
+
+  complex_id = H5Tcreate(H5T_COMPOUND, sizeof(npy_complex128));
+  if (strcmp(byteorder, "little") == 0)
+    float_id = H5Tcopy(H5T_IEEE_F64LE);
+  else
+    float_id = H5Tcopy(H5T_IEEE_F64BE);
+  H5Tinsert(complex_id, "r", HOFFSET(npy_complex128, real), float_id);
+  H5Tinsert(complex_id, "i", HOFFSET(npy_complex128, imag), float_id);
   H5Tclose(float_id);
   return complex_id;
 }
 
-/* return the number of significant bits in the
-   real and imaginary parts */
-/* This is effectively an extension of H5Tget_precision
-   to handle complex types */
+
+/* Return the number of significant bits in the real and imaginary parts */
+/* This is actually an extension of H5Tget_precision to handle complex types */
 size_t get_complex_precision(hid_t type_id) {
   hid_t real_type;
   size_t result;
@@ -732,3 +745,35 @@ size_t get_complex_precision(hid_t type_id) {
 }
 
 /* End of complex additions */
+
+
+/* The get_len_of_range has been taken from Python interpreter */
+
+/* Return number of items in range/xrange (lo, hi, step).  step > 0
+ * required.  Return a value < 0 if & only if the true value is too
+ * large to fit in a signed long.
+ */
+hsize_t get_len_of_range(hsize_t lo, hsize_t hi, hsize_t step)
+{
+  /* -------------------------------------------------------------
+     If lo >= hi, the range is empty.
+     Else if n values are in the range, the last one is
+     lo + (n-1)*step, which must be <= hi-1.  Rearranging,
+     n <= (hi - lo - 1)/step + 1, so taking the floor of the RHS gives
+     the proper value.  Since lo < hi in this case, hi-lo-1 >= 0, so
+     the RHS is non-negative and so truncation is the same as the
+     floor.  Letting M be the largest positive long, the worst case
+     for the RHS numerator is hi=M, lo=-M-1, and then
+     hi-lo-1 = M-(-M-1)-1 = 2*M.  Therefore unsigned long has enough
+     precision to compute the RHS exactly.
+     Note: We are using here 64 bit ints because PyTables can deal
+     with 64-bit addresses even on 32-bit platforms.
+     F. Altet 2006-09-25
+     ---------------------------------------------------------------*/
+  hsize_t n = 0;
+  if (lo < hi) {
+    hsize_t diff = hi - lo - 1;
+    n = (hsize_t)(diff / step + 1);
+  }
+  return n;
+}
