@@ -4,7 +4,7 @@
 #       Created: October 14, 2002
 #       Author:  Francesc Altet - faltet@carabos.com
 #
-#       $Id: leaf.py 3094 2007-07-03 10:14:15Z faltet $
+#       $Id: leaf.py 3334 2007-11-22 16:56:15Z faltet $
 #
 ########################################################################
 
@@ -45,7 +45,7 @@ from tables.exceptions import PerformanceWarning
 
 
 
-__version__ = "$Revision: 3094 $"
+__version__ = "$Revision: 3334 $"
 
 
 def calc_chunksize(expectedsizeinMB):
@@ -310,8 +310,8 @@ class Leaf(Node):
 
     def __str__(self):
 
-        """The string reprsentation choosed for this object is its pathname
-        in the HDF5 object tree.
+        """The string representation for this object is its pathname in
+        the HDF5 object tree plus some additional metainfo.
         """
 
         # Get this class name
@@ -409,12 +409,12 @@ class Leaf(Node):
             maxrowsize = BUFFERTIMES * buffersize
             if rowsize > maxrowsize:
                 warnings.warn("""\
-array or table ``%s`` is exceeding the maximum recommended rowsize (%d bytes);
-be ready to see PyTables asking for *lots* of memory and possibly slow I/O.
-You may want to reduce the rowsize by trimming the value of dimensions
-that are orthogonal to the main dimension of this array or table.
-Alternatively, in case you have specified a very small chunksize,
-you may want to increase it."""
+The Leaf ``%s`` is exceeding the maximum recommended rowsize (%d bytes);
+be ready to see PyTables asking for *lots* of memory and possibly slow
+I/O.  You may want to reduce the rowsize by trimming the value of
+dimensions that are orthogonal (and preferably close) to the main
+dimension of this leave.  Alternatively, in case you have specified a
+very small/large chunksize, you may want to increase/decrease it."""
                               % (self._v_pathname, maxrowsize),
                                  PerformanceWarning)
 # It is difficult to forsee the level of code nesting to reach user code.
