@@ -5,7 +5,7 @@
 #       Author:  Ivan Vilata - reverse:com.carabos@ivilata
 #
 #       $Source$
-#       $Id: undoredo.py 1293 2005-10-20 18:37:08Z faltet $
+#       $Id: undoredo.py 2381 2007-02-16 18:06:40Z ivilata $
 #
 ########################################################################
 
@@ -29,14 +29,14 @@ Misc variables:
     Repository version of this file.
 """
 
-from tables.utils import splitPath
+from tables.path import splitPath
 
 
 
 __docformat__ = 'reStructuredText'
 """The format of documentation strings in this module."""
 
-__version__ = '$Revision: 1293 $'
+__version__ = '$Revision: 2381 $'
 """Repository version of this file."""
 
 
