@@ -4,7 +4,7 @@
 #       Created: November 12, 2003
 #       Author:  Francesc Altet - faltet@carabos.com
 #
-#       $Id: vlarray.py 2912 2007-05-22 15:31:47Z ivilata $
+#       $Id: vlarray.py 3312 2007-10-28 12:33:42Z ivilata $
 #
 ########################################################################
 
@@ -32,6 +32,7 @@ import warnings
 import numpy
 
 from tables import hdf5Extension
+from tables.utilsExtension import lrange
 from tables.utils import convertToNPAtom, convertToNPAtom2, idx2long, \
      correct_byteorder
 
@@ -41,7 +42,7 @@ from tables.flavor import internal_to_flavor
 from tables.leaf import Leaf, calc_chunksize
 
 
-__version__ = "$Revision: 2912 $"
+__version__ = "$Revision: 3312 $"
 
 # default version for VLARRAY objects
 #obversion = "1.0"    # initial version
@@ -129,7 +130,7 @@ class VLArray(hdf5Extension.VLArray, Leaf):
         # Create a VLArray:
         fileh = tables.openFile('vlarray1.h5', mode='w')
         vlarray = fileh.createVLArray(fileh.root, 'vlarray1',
-                                      tables.Int32Atom(shape=1),
+                                      tables.Int32Atom(shape=()),
                                       \"ragged array of ints\",
                                       filters=tables.Filters(1))
         # Append some (variable length) rows:
@@ -628,7 +629,7 @@ be zero."""
             vlarray[0] = vlarray[0] * 2 + 3
             vlarray[99, 3:] = arange(96) * 2 + 3
             # Negative values for start and stop (but not step) are supported.
-            vlarray[99, -99:-89:2] = vlarray[5] * 2 + 3</screen>
+            vlarray[99, -99:-89:2] = vlarray[5] * 2 + 3
         """
 
         self._v_file._checkWritable()
@@ -749,7 +750,7 @@ be zero."""
             atomsize = self.atom.base.size
         else:
             atomsize = self.atom.size
-        for start2 in xrange(start, stop, step*nrowsinbuf):
+        for start2 in lrange(start, stop, step*nrowsinbuf):
             # Save the records on disk
             stop2 = start2+step*nrowsinbuf
             if stop2 > stop:
